// java wrapper for vtkHomogeneousTransform object
//

package vtk;
import vtk.*;

public class vtkHomogeneousTransform extends vtkAbstractTransform
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void TransformPoints_2(vtkPoints id0,vtkPoints id1);
  public void TransformPoints(vtkPoints id0,vtkPoints id1)
    { TransformPoints_2(id0,id1); }

  private native void GetMatrix_3(vtkMatrix4x4 id0);
  public void GetMatrix(vtkMatrix4x4 id0)
    { GetMatrix_3(id0); }

  private native long GetMatrix_4();
  public vtkMatrix4x4 GetMatrix() {
    long temp = GetMatrix_4();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetHomogeneousInverse_5();
  public vtkHomogeneousTransform GetHomogeneousInverse() {
    long temp = GetHomogeneousInverse_5();

    if (temp == 0) return null;
    return (vtkHomogeneousTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void InternalTransformPoint_6(double id0[],double id1[]);
  public void InternalTransformPoint(double id0[],double id1[])
    { InternalTransformPoint_6(id0,id1); }

  public vtkHomogeneousTransform() { super(); }

  public vtkHomogeneousTransform(long id) { super(id); }

}
